Coverage report

File | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
src/symphra_modules/__init__.py | 6 | 0 | 47 | 0 | 0 | 100.00%
src/symphra_modules/abc.py | 48 | 0 | 49 | 14 | 2 | 96.77%
src/symphra_modules/config.py | 31 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/events/__init__.py | 3 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/events/bus.py | 45 | 2 | 0 | 18 | 2 | 90.48%
src/symphra_modules/events/types.py | 41 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/exceptions.py | 19 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/loader/__init__.py | 4 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/loader/base.py | 32 | 5 | 20 | 12 | 4 | 75.00%
src/symphra_modules/loader/directory.py | 98 | 51 | 0 | 38 | 2 | 49.26%
src/symphra_modules/loader/package.py | 25 | 1 | 0 | 6 | 1 | 93.55%
src/symphra_modules/manager.py | 160 | 43 | 0 | 52 | 8 | 70.28%
src/symphra_modules/registry.py | 119 | 20 | 0 | 16 | 3 | 82.96%
src/symphra_modules/resolver/__init__.py | 2 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/resolver/dependency.py | 94 | 0 | 0 | 48 | 2 | 98.59%
src/symphra_modules/utils/__init__.py | 5 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/utils/logger.py | 33 | 6 | 25 | 4 | 2 | 78.38%
Total | 765 | 128 | 141 | 208 | 26 | 80.88%

No items found using the specified filter.